#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-79iCPyqxieHCAdx5QOaB53
key:                  postgrest-10.1.0-79iCPyqxieHCAdx5QOaB53
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  b703cf2eb2b77bf5b2e51eea68d21f65
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-79iCPyqxieHCAdx5QOaB53
depends:
    HTTP-4000.4.1-56k6XzW1iWd5pdtORF53u7
    Ranged-sets-0.5.0-C38f3fQOYNq7EYfqMyNPrd
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie
    auto-update-0.1.6-CfQKMkm200U8skQBi3KEWD base-4.18.2.1
    base64-bytestring-1.2.1.0-EmY0767ffFE8tBeH3slcY bytestring-0.11.5.3
    case-insensitive-1.2.1.0-GQhuCOunwpP4Wu7eC91bZR
    cassava-0.5.4.1-5ZtQtuMBH061ciGWCN2UKt
    configurator-pg-0.2.11-FjyaPDWyiXZABytJe2IW0e containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-DJfTESfI3pa1Kspx8z8l8o
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-9OA2t4dPh5U9FTJt3f3QK0
    hasql-dynamic-statements-0.3.1.2-E0JDxBQoRH9Cx3j72EyxSw
    hasql-notifications-0.2.0.5-6MeMWfdflk8MAWv5TNJo4
    hasql-pool-0.8.0.2-JGx6TaiYFnk7QoDYDP3SsD
    hasql-transaction-1.0.1.2-HEzh8upHNoyEuIyf9IpLWV
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-CCQmPdMOAQMGVpO7SZrjGJ
    insert-ordered-containers-0.2.5.3-JqWD6eUuzveK17mRyLQRzw
    interpolatedstring-perl6-1.0.2-Jxolljn9wZVL2zlx1v5vo
    jose-0.10-4RVEplDtK2c65H4b68ZdRu lens-5.3.4-kk6OqUq8ZY4lLpzN7435U
    lens-aeson-1.2.3-K1JngaG9OfHHT9om9Ah6qo mtl-2.3.1
    network-3.1.4.0-9dONp0onFcbAlDBEoFNGkb
    network-uri-2.6.4.2-F4vpljQpQbT2777eQcDCfi
    optparse-applicative-0.18.1.0-EpSL3bYuMS8I8b55RDM0x parsec-3.1.16.1
    protolude-0.3.5-EioQAuPESX62ZWXXPBNB9o
    regex-tdfa-1.3.2.5-6VokBrH99ZuK2RS5akjMTl
    retry-0.9.3.1-Em8OXhcO1BnFSqwIXyQqas
    scientific-0.3.8.1-9lNiUg0NFGt8fB4Ap5FVsD
    swagger2-2.8.10-ENCJRPonENk7uoCp8maZ5H text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-HfKtyefgs0b2egKrxLGXU0
    vault-0.3.1.6-Jy2RdBzrYZhL24gacTSqUt
    vector-0.13.2.0-7eILYIgfGZSAohY3MIpZY
    wai-3.2.4-3XyCh5m71lWJYF48VLLZUp
    wai-cors-0.2.7-DIPKtSgS2l6C2CGXVKzgJd
    wai-extra-3.1.18-LZb0ZvCfLGtGdgg4u5HHu3
    wai-logger-2.5.0-DXGT5hmM8jS3TVtROXC2tb
    warp-3.4.0-9HslBeBY1wf9o4ROK9xeo9

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

